@@ -19,8 +19,8 @@
 # THE SOFTWARE.
 #
 
-"""Package defining the class containing a standard SMTP reply made up of a code
-and a message, as well as a few pre-defined standard replies.
+"""Package defining the class containing a standard SMTP reply made up of a
+code and a message, as well as a few pre-defined standard replies.
 
 .. _ENHANCEDSTATUSCODES: http://tools.ietf.org/html/rfc2034
 
@@ -72,15 +72,28 @@ class Reply(object):
         #: which is useful for asynchronous replies such as timeouts.
         self.newline_first = False
 
+    def __eq__(self, other):
+        return self.code == other.code and self.message == other.message
+
+    def __repr__(self):
+        """Converts the reply into a string that shows appropriate internals of
+        the object.
+
+        :rtype: str
+
+        """
+        return '<Reply code={0!r} message={1!r}>'.format(self.code,
+                                                         self.message)
+
     def __str__(self):
         """Converts the reply into a single string.
 
         :returns: The code, ENHANCEDSTATUSCODES_ string, and the message,
                   separated by spaces.
-        :rtype: string
+        :rtype: str
 
         """
-        return ' '.join((self.code, self.message))
+        return '{0} {1}'.format(self.code, self.message)
 
     def __nonzero__(self):
         """Defines the truth-testing operation for |Reply| objects. This will
