@@ -1,6 +1,8 @@
 
 import unittest
 
+from assertions import *
+
 from slimta.smtp.extensions import Extensions
 
 
@@ -11,37 +13,37 @@ class TestSmtpExtensions(unittest.TestCase):
         self.ext.extensions = {'EMPTY': None, 'TEST': 'STUFF'}
 
     def test_contains(self):
-        self.assertTrue('TEST' in self.ext)
-        self.assertTrue('test' in self.ext)
-        self.assertFalse('BAD' in self.ext)
+        assert_true('TEST' in self.ext)
+        assert_true('test' in self.ext)
+        assert_false('BAD' in self.ext)
 
     def test_reset(self):
-        self.assertTrue('TEST' in self.ext)
+        assert_true('TEST' in self.ext)
         self.ext.reset()
-        self.assertFalse('TEST' in self.ext)
+        assert_false('TEST' in self.ext)
 
     def test_add(self):
         self.ext.add('new')
-        self.assertTrue('NEW' in self.ext)
+        assert_true('NEW' in self.ext)
 
     def test_drop(self):
-        self.assertTrue(self.ext.drop('test'))
-        self.assertFalse('TEST' in self.ext)
-        self.assertFalse(self.ext.drop('BAD'))
+        assert_true(self.ext.drop('test'))
+        assert_false('TEST' in self.ext)
+        assert_false(self.ext.drop('BAD'))
 
     def test_getparam(self):
-        self.assertEqual(None, self.ext.getparam('BAD'))
-        self.assertEqual(None, self.ext.getparam('EMPTY'))
-        self.assertEqual('STUFF', self.ext.getparam('TEST'))
+        assert_equal(None, self.ext.getparam('BAD'))
+        assert_equal(None, self.ext.getparam('EMPTY'))
+        assert_equal('STUFF', self.ext.getparam('TEST'))
 
     def test_getparam_filter(self):
         ret = self.ext.getparam('TEST', lambda x: x.strip('F'))
-        self.assertEqual('STU', ret)
+        assert_equal('STU', ret)
         ret = self.ext.getparam('EMPTY', lambda x: x)
-        self.assertEqual(None, ret)
+        assert_equal(None, ret)
 
     def test_getparam_filter_valueerror(self):
-        self.assertEqual(None, self.ext.getparam('TEST', int))
+        assert_equal(None, self.ext.getparam('TEST', int))
 
     def test_parse_string(self):
         ext = Extensions()
@@ -49,11 +51,11 @@ class TestSmtpExtensions(unittest.TestCase):
 the header
 EXT1
 PARSETEST DATA""")
-        self.assertEqual('the header', header)
-        self.assertTrue('EXT1' in ext)
-        self.assertTrue('PARSETEST' in ext)
-        self.assertEqual(None, ext.getparam('EXT1'))
-        self.assertEqual('DATA', ext.getparam('PARSETEST'))
+        assert_equal('the header', header)
+        assert_true('EXT1' in ext)
+        assert_true('PARSETEST' in ext)
+        assert_equal(None, ext.getparam('EXT1'))
+        assert_equal('DATA', ext.getparam('PARSETEST'))
 
     def test_build_string(self):
         possibilities = ("""\
@@ -64,7 +66,7 @@ the header
 TEST STUFF
 EMPTY""")
         ret = self.ext.build_string('the header').replace('\r', '')
-        self.assertTrue(ret in possibilities)
+        assert_true(ret in possibilities)
 
     def test_build_string_valueerror(self):
         class MyExtension(object):
@@ -75,7 +77,7 @@ EMPTY""")
         ext = Extensions()
         ext.extensions = {'ONE': 'OK VALUE', 'TWO': MyExtension()}
         expected = """the header\r\nONE OK VALUE"""
-        self.assertEqual(expected, ext.build_string('the header'))
+        assert_equal(expected, ext.build_string('the header'))
 
 
 # vim:et:fdm=marker:sts=4:sw=4:ts=4
